@@ -5,7 +5,7 @@ use Carp;
 use Text::CSV_XS;
 use Scalar::Util qw( reftype );
 use Cwd;
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
@@ -863,7 +863,7 @@ sub write_pathified_to_csv {
         map { $columns_in->[$_]  }
         grep { ! $path_columns{$columns_in->[$_]} }
         (0..$#{$columns_in});
-    my @columns_out = (qw| path |);
+    my @columns_out = ( $pathified->[0]->[0]);
     push @columns_out, @non_path_columns_in;
 
     my $cwd = cwd();
